@@ -46,12 +46,13 @@ $doc_content =<<EOF;
 </ruleset>
 EOF
 
-$conn->connection->doc_content($doc_content);
+#$conn->document->content($doc_content);
+print $conn->document->fetch;
 
-#print $conn->replace;
-#print $conn->create;
+#print $conn->connection->replace;
+#print $conn->connection->create;
 #print $conn->delete;
-print $conn->fetch;
+#print $conn->connection->fetch;
 
 1;
 
